summaryrefslogtreecommitdiff
path: root/src/network/network_internal.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/network/network_internal.h')
-rw-r--r--src/network/network_internal.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/network/network_internal.h b/src/network/network_internal.h
index 2498d50d4..06dca992f 100644
--- a/src/network/network_internal.h
+++ b/src/network/network_internal.h
@@ -149,8 +149,8 @@ bool IsNetworkCompatibleVersion(const char *version);
* Everything we need to know about a command to be able to execute it.
*/
struct CommandPacket : CommandContainer {
- /** Make sure the pointer is NULL. */
- CommandPacket() : next(NULL), company(INVALID_COMPANY), frame(0), my_cmd(false) {}
+ /** Make sure the pointer is nullptr. */
+ CommandPacket() : next(nullptr), company(INVALID_COMPANY), frame(0), my_cmd(false) {}
CommandPacket *next; ///< the next command packet (if in queue)
CompanyID company; ///< company that is executing the command
uint32 frame; ///< the frame in which this packet is executed